@@ -60,8 +60,11 @@ kSearchAlgorithms = ['hyperopt', 'skopt', 'bohb', 'ax', 'tune', 'random', 'grid'
 kSchedulers = ['asynchyperband', 'bohbhyperband', 'pbt']
 kMetricMode = ['min', 'max']
 
-
-
+kDefaultSearchAlgorithm = 'random'
+kDefaultScheduler = 'asynchyperband'
+kDefaultMetric = 'loss'
+kDefaultMetricMode = 'min'
+kDefaultTrials = 1
 
 
 kDefaultOutDS = 'user.${{RUCIO_ACCOUNT}}.hpogrid.{HPO_PROJECT_NAME}.out.$(date +%Y%m%d%H%M%S)'
