@@ -7,22 +7,24 @@ import tempfile
 
 import hpogrid
 
+from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper, stylus
 from hpogrid.idds_interface.idds_utils import transpose_config
-from hpogrid.components.validation import validate_project_config
+from hpogrid.configuration import ProjectConfiguration
 
 class GridHandler():
+    
+    _USAGE_ = 'hpogrid submit [-h|--help] [<args>]'
+    _DESCRIPTION_ = 'Tool for grid job submission'    
+    
     def __init__(self):
+        pass
 
-        # submit grid job via hpogrid executable
-        if len(sys.argv) > 1:
-            self.run_parser()
-
-    def get_parser(self):
-        parser = argparse.ArgumentParser(
-                    formatter_class=argparse.RawDescriptionHelpFormatter)
-        parser.add_argument('input', help='the name of project or configuration'
+    def get_parser(self, **kwargs):
+        parser = CLIParser(description=self._DESCRIPTION_,
+                           usage=self._USAGE_, **kwargs) 
+        parser.add_argument('config_input', help='the name of project or configuration'
                             ' file for grid job submission')               
         parser.add_argument('-n','--n_jobs', type=int, help='number of jobs to submit',
             default=1)
@@ -40,20 +42,11 @@ class GridHandler():
         parser.add_argument('-d','--debug', action='store_true', help='debug mode')        
         return parser
 
-    def run_parser(self):
+    def run_parser(self, args=None):
         parser = self.get_parser()
-        if os.path.basename(sys.argv[0]) == 'hpogrid':
-            args, extra = parser.parse_known_args(sys.argv[2:])
-        else:
-            args, extra = parser.parse_known_args(sys.argv[1:])
-        self.submit(args.input, 
-                    n_jobs=args.n_jobs,
-                    site=args.site,
-                    time=args.time,
-                    search_points = args.search_points,
-                    mode=args.mode,
-                    debug=args.debug,
-                    extra=extra)
+        args, extra = parser.parse_known_args(args)
+        args = vars(args)
+        self.submit(**args, extra=extra)
     
     @staticmethod
     def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid', debug=False, extra=[]):
@@ -69,7 +62,7 @@ class GridHandler():
     @staticmethod
     def preprocess_config(config_input):
         config = hpogrid.load_configuration(config_input)
-        config = validate_project_config(config)
+        config = ProjectConfiguration._validate(config)
         project_name = config['project_name']
         if not helper.is_project(project_name):
             print('INFO: Creating project directory for "{}"'.format(project_name))
@@ -136,8 +129,13 @@ class GridHandler():
         if not site:
             site = grid_config['site']
                 
-        if (site != 'ANY'):
-            options['site'] = site
+        if site:
+            if isinstance(site, str):
+                options['site'] = site
+            elif isinstance(site, list):
+                options['site'] = ','.join(site)
+            else:
+                raise ValueError('Invalid site settings: {}'.format(site))
             # specify architecture for gpu/cpu site
             if 'GPU' in site:
                 options['architecture'] = 'nvidia-gpu'
@@ -191,11 +189,16 @@ class GridHandler():
         if not site:
             site = grid_config['site']
                 
-        if (site != 'ANY'):
-            options['site'] = site
+        if site:
+            if isinstance(site, str):
+                options['site'] = site
+            elif isinstance(site, list):
+                options['site'] = ','.join(site)
+            else:
+                raise ValueError('Invalid site settings: {}'.format(site))
             # specify architecture for gpu/cpu site
             if 'GPU' in site:
-                options['cmtConfig'] = 'nvidia-gpu'
+                options['architecture'] = 'nvidia-gpu'
                 
         
         command = 'prun {} {}'.format(stylus.join_options(options), ' '.join(extra))
