@@ -14,19 +14,23 @@ import ray
 from ray import tune
 
 import hpogrid
+from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper
 from hpogrid.idds_interface import idds_utils
 
 
 class JobBuilder():
+    
+    _USAGE_ = 'hpogrid run [<args>]'
+    _DESCRIPTION_ = 'Run hyperparameter optimization from a project/configuration file'    
+    
     def __init__(self, parser=False):
         self.reset()
-    
-    @staticmethod       
-    def get_parser():
-        parser = argparse.ArgumentParser(description='Run hyperparameter optimization '
-                                        'from a project/configuration file')     
+        
+    def get_parser(self, **kwargs):
+        parser = CLIParser(description=self._DESCRIPTION_,
+                           usage=self._USAGE_, **kwargs)    
         parser.add_argument('config_input', help='Name of project/configuration file')  
         parser.add_argument('-p', '--search_points', help='A json file containing the manual'
                             ' search points to run', default=None)    
@@ -35,7 +39,13 @@ class JobBuilder():
                             choices=['local', 'grid', 'idds'],
                             default='local')   
         return parser
-
+    
+    def run_parser(self, args=None):
+        parser = self.get_parser()
+        args = vars(parser.parse_args(args))
+        self.load(**args)
+        self.run()
+        
     @property
     def algorithm(self) -> str:
         return self._algorithm
@@ -418,16 +428,17 @@ class JobBuilder():
         from ray.tune.logger import NoopLogger, MLFLowLogger
         return [NoopLogger, MLFLowLogger]
     
-    @classmethod
-    def from_input(cls, config_input: [Dict, str],
-                    search_points=None,
-                    mode='local'):
-        
+    def setup(self, mode='local'):
         hpogrid.setup(mode)
         
+    def load(self, config_input: [Dict, str], search_points=None, mode='local'):
+        
+        self.reset()
+        self.setup(mode)
+
         input_as_project = helper.is_project(config_input)
         config = helper.load_configuration(config_input)
-        
+
         # if input is a project name, set scripts path to 
         # where the scripts are stored in the project directory
         # if input is a configuration file, set scripts path to
@@ -436,53 +447,60 @@ class JobBuilder():
             scripts_path = helper.get_scripts_path(config_input)
         else:
             scripts_path = helper.pretty_dirname(config['scripts_path'])
-        
-        job = JobBuilder()
-        job.project_name = config['project_name']
-        job.scripts_path = scripts_path
+   
+        self.project_name = config['project_name']
+        self.scripts_path = scripts_path
         
         # Load search space
-        job.search_space = config['search_space']
-        
+        self.search_space = config['search_space']
+
         # Load hpo configuration
-        job.algorithm = config['hpo_config']['algorithm']
-        job.metric = config['hpo_config']['metric']
-        job.mode = config['hpo_config']['mode']
-        job.scheduler = config['hpo_config']['scheduler']
-        job.scheduler_param = config['hpo_config']['scheduler_param']
-        job.algorithm_param = config['hpo_config']['algorithm_param']
-        job.num_trials = config['hpo_config']['num_trials']
-        job.max_concurrent = config['hpo_config']['max_concurrent']
-        job.verbose = config['hpo_config']['verbose']
-        job.log_dir = config['hpo_config'].get('log_dir', None)
-        job.stop = config['hpo_config'].get('stop', None)
-        job.resource_per_trial = config['hpo_config'].get('resource', None)
-        job.extra_metrics = config['hpo_config'].get('extra_metrics', None)
+        self.algorithm = config['hpo_config']['algorithm']
+        self.metric = config['hpo_config']['metric']
+        self.mode = config['hpo_config']['mode']
+        self.scheduler = config['hpo_config']['scheduler']
+        self.scheduler_param = config['hpo_config']['scheduler_param']
+        self.algorithm_param = config['hpo_config']['algorithm_param']
+        self.num_trials = config['hpo_config']['num_trials']
+        self.max_concurrent = config['hpo_config']['max_concurrent']
+        self.verbose = config['hpo_config']['verbose']
+        self.log_dir = config['hpo_config'].get('log_dir', None)
+        self.stop = config['hpo_config'].get('stop', None)
+
+        self.resource_per_trial = config['hpo_config'].get('resource', None)
+
+        self.extra_metrics = config['hpo_config'].get('extra_metrics', None)
         
         # configuration for idds
         if (not search_points) and hpogrid.is_idds_job():
             search_points = idds_utils.get_search_points()
-        
+
         if search_points:
             if isinstance(search_points, str):
                 with open(search_points, 'r') as f:
                     search_points = json.load(f)
-            job.search_points = search_points
+            self.search_points = search_points
             from hpogrid.search_space.skopt_space import SkOptSpace
             skopt_search_points = SkOptSpace.transform(search_points, 
                                       reference=job.search_space)
-            job.algorithm = 'skopt'
-            job.scheduler = None
-            job.scheduler_param = {}
-            job.algorithm_param = {'points_to_evaluate': skopt_search_points}
-            job.num_trials = len(skopt_search_points)
+            self.algorithm = 'skopt'
+            self.scheduler = None
+            self.scheduler_param = {}
+            self.algorithm_param = {'points_to_evaluate': skopt_search_points}
+            self.num_trials = len(skopt_search_points)
 
         # Load model configuration
-        job.model_script = config['model_config']['script']
-        job.model_name = config['model_config']['model']
-        job.model_param = config['model_config']['param']
+        self.model_script = config['model_config']['script']
+        self.model_name = config['model_config']['model']
+        self.model_param = config['model_config']['param']
 
-        job._hyperparameters = list(job.search_space.keys())
+        self._hyperparameters = list(self.search_space.keys())
     
+    @classmethod
+    def from_input(cls, config_input: [Dict, str],
+                    search_points=None,
+                    mode='local'):
+        job = JobBuilder()
+        job.load(config_input, search_points, mode)
         return job
     
