@@ -1,4 +1,5 @@
-import sys, os
+import os
+import sys
 import ssl
 import json
 #import re
@@ -8,7 +9,6 @@ from tqdm import tqdm
 import argparse
 import datetime
 import pandas as pd
-from pdb import set_trace
 
 try:
     from urllib.parse import urlencode
@@ -30,9 +30,8 @@ try:
 except:
     raise ImportError('No module named \'pandatools\'. Please do '
         '\'setupATLAS\' and \'lsetup panda\' first ')
-
-
-kPandaTaskManagerMethods = ['show', 'kill', 'retry', 'killAndRetry']
+    
+from hpogrid.utils.cli_parser import CLIParser
 
 kPanDA_URL = 'https://bigpanda.cern.ch/'
 kPanDA_TaskURL = 'https://bigpanda.cern.ch/tasks/'
@@ -84,68 +83,78 @@ kColorDict = {
 
 class PandaTaskManager():
 
-    def __init__(self, enable_parser=False):
+    _ACTION_HELP_MESSAGE_ = {
+        'show': 'Display PanDA task status',
+        'kill': 'Kill a task by JediTaskID',
+        'retry': 'Retry a task by JediTaskID',
+        'killAndRetry': 'Kill and retry a task by JediTaskID',
+    }    
+
+    _USAGE_ = 'hpogrid tasks [-h|--help] {action} [<args>]'
+    _DESCRIPTION_ = 'Tool for PanDA task management'    
+
+    def __init__(self):
         print('INFO: Verifying Grid Proxy...')
         self.pbook = PBookCore.PBookCore()
         print('INFO: Verification is Successful.')
         self.context = ssl.SSLContext()
         #self.context = ssl._create_unverified_context()
         self.context.load_verify_locations(**kPanDAVerifyPath)
+            
+    def get_parser(self, **kwargs):
+        usage_str = self._USAGE_.format(action='<action>')
+        parser = CLIParser(description=self._DESCRIPTION_,
+                           usage=usage_str, **kwargs) 
+        parser.set_title('The most commonly used actions are')
+        action_subparser = parser.add_subparsers(dest="action", parser_class=CLIParser)   
 
-        # call functions via hpogrid executable
-        if enable_parser:
-            self.run_parser()
-
-    def run_parser(self):
-        base_parser = self.get_parser()
-        args = base_parser.parse_args(sys.argv[2:3])
-        method = args.method
-        method_parser = self.get_parser(method)
-        if not method_parser:
-            print('Unrecognized method: {}'.format(method))
-            base_parser.print_help()
-            exit(1)
-        args = method_parser.parse_args(sys.argv[3:])
-        getattr(self, method)(args)
-
-    def get_parser(self, method=None):
-        parser = None
-        if method == None:
-            parser = argparse.ArgumentParser()
-            parser.add_argument('method', help='Method to call',
-                choices=kPandaTaskManagerMethods)    
-        elif method == 'show':
-            parser = argparse.ArgumentParser(description='show PanDA task status',
-                        formatter_class=argparse.RawDescriptionHelpFormatter)      
-            parser.add_argument('-u','--username',
-                help='filter tasks by username')
-            parser.add_argument('-l','--limit', type=int, default=1000,
-                help='the maximum number of tasks to query')
-            parser.add_argument('-d', '--days', type=int, default=30,
-                help='filter tasks within the recent N days')
-            parser.add_argument('-n', '--taskname', 
-                help='filter tasks by taskname (accept wildcards)')
-            parser.add_argument('-i', '--jeditaskid',
-                help='only show the task with the specified jeditaskid')
-            parser.add_argument('-m', '--metadata', action='store_true',
-                help='print out the metadata of a task')
-            parser.add_argument('-s', '--status', nargs='+',
-                help='filter tasks by task status')
-            parser.add_argument('-y', '--sync', action='store_true',
-                help='force no caching on the PanDA server')
-            parser.add_argument('-r', '--taskid_range',
-                help='filter tasks by jeditaskid range')
-            parser.add_argument('-o', '--output',
-                help='output result with the filename if specified')
-            parser.add_argument('-c', '--outcol',
-                help='data columns to be saved in output',
-                default=kOutputColumns)
-        elif (method in ['kill', 'retry', 'killAndRetry']):
-            parser = argparse.ArgumentParser(description='kill/retry a PanDA task',
-                        formatter_class=argparse.RawDescriptionHelpFormatter)   
-            parser.add_argument('jeditaskid', help='jeditaskid of the task')   
+        action_parsers = {}
+        for action, msg in self._ACTION_HELP_MESSAGE_.items():
+            usage_str = self._USAGE_.format(action=action)
+            args = {'help': msg, 'description': msg, 'usage': usage_str, 'prog': usage_str}
+            action_parsers[action] = action_subparser.add_parser(action, **args)  
+            
+        action_parsers['show'].add_argument('-u','--username',
+            help='filter tasks by username')
+        action_parsers['show'].add_argument('-l','--limit', type=int, default=1000,
+            help='the maximum number of tasks to query')
+        action_parsers['show'].add_argument('-d', '--days', type=int, default=30,
+            help='filter tasks within the recent N days')
+        action_parsers['show'].add_argument('-n', '--taskname', 
+            help='filter tasks by taskname (accept wildcards)')
+        action_parsers['show'].add_argument('-i', '--jeditaskid',
+            help='only show the task with the specified jeditaskid')
+        action_parsers['show'].add_argument('-m', '--metadata', action='store_true',
+            help='print out the metadata of a task')
+        action_parsers['show'].add_argument('-s', '--status', nargs='+',
+            help='filter tasks by task status')
+        action_parsers['show'].add_argument('-y', '--sync', action='store_true',
+            help='force no caching on the PanDA server')
+        action_parsers['show'].add_argument('-r', '--taskid_range',
+            help='filter tasks by jeditaskid range')
+        action_parsers['show'].add_argument('-o', '--output',
+            help='output result with the filename if specified')
+        action_parsers['show'].add_argument('-c', '--outcol',
+            help='data columns to be saved in output',
+            default=kOutputColumns)
+        
+        for action in ['kill', 'retry', 'killAndRetry']:
+            action_parsers[action].add_argument('jeditaskid', help='JediTaskID of the task')   
 
         return parser
+            
+    def run_parser(self, args=None):
+        parser = self.get_parser()
+        args = vars(parser.parse_args(args))  
+        action = args.pop('action')
+        if action is None:
+            parser.print_help()
+            sys.exit(0)
+        if not hasattr(self, action):
+            print('Unrecognized action: {}'.format(action))
+            parser.print_help()
+            sys.exit(0)
+        getattr(self, action)(args)        
 
     def get_response(self, req, out_json=True):
         response = urlopen(req, context=self.context).read().decode('utf-8')
@@ -348,16 +357,15 @@ class PandaTaskManager():
 
     # show task status
     def show(self, args):
-        params = vars(args)
-        output = params.pop('output', None)
-        outcol = params.pop('outcol', None)
+        output = args.pop('output', None)
+        outcol = args.pop('outcol', None)
         print('INFO: Fetching PanDA Tasks...')
-        datasets = self.query_tasks(**params)
+        datasets = self.query_tasks(**args)
         
         print('')
         self.print_standard(datasets)
         
-        if args.metadata:
+        if args['metadata']:
             print('')
             self.print_metadata(datasets)       
 
@@ -369,15 +377,15 @@ class PandaTaskManager():
         return pbookCore.get_active_tasks()
 
     def kill(self, args):
-        task_id = int(args.jeditaskid)
+        task_id = int(args['jeditaskid'])
         self.pbook.kill(task_id)
 
     def retry(self, args):
-        task_id = int(args.jeditaskid)
+        task_id = int(args['jeditaskid'])
         self.pbook.retry(task_id)
 
     def killAndRetry(self, args):
-        task_id = int(args.jeditaskid)
+        task_id = int(args['jeditaskid'])
         self.pbook.killAndRetry(task_id)
 
 
